mysql.exceptions.internal.Data_Truncated

Package mysql :: Package exceptions :: Module internal :: Class Data_Truncated |
[hide private]
[frames] | no frames]

# Class Data_Truncated

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                              Data_Truncated

Data was truncated in the last fetch.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`